GlobNode class abstract

Implementers

Constructors

GlobNode(String? source, int? position)

Properties

crossesDirectory → bool?
Returns true if node crosses directory; otherwise false.
no setter
hashCode → int
The hash code for this object.
no setterinherited
position → int?
Start position of this node in the source.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source → String?
Text source of this node;
final
strict → bool?
Returns true if node is strict; otherwise false.
no setter
type → GlobNodeTypes
Returns type of this node.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
Returns srting representation.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited