GlobNodeSegment class

Inheritance

Constructors

GlobNodeSegment(String source, int? position, bool? isRoot, List<GlobNode>? nodes)

Properties

crossesDirectory → bool?
Returns true if node crosses directory; otherwise false.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
isRoot → bool?
Returns true if node if is a root segment; otherwise false.
no setter
nodes → List<GlobNode>
Returns elements of this node.
no setterinherited
onlyDirectory → bool?
Returns true if node matches only directory; otherwise false.
no setter
position → int?
Start position of this node in the source.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source → String?
Text source of this node;
finalinherited
strict → bool?
Returns true if node is strict; otherwise false.
no setterinherited
type → GlobNodeTypes
Returns type of this node.
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
Returns srting representation.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited