GlobNodeSegments class

Inheritance

Constructors

GlobNodeSegments(String? source, int position, List<GlobNodeSegment>? nodes)

Properties

crossesDirectory → bool?
Returns true if node crosses directory; otherwise false.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
isAbsolute → bool?
Returns true if node if is an absolute path; otherwise false.
no setter
nodes → List<GlobNodeSegment>
Returns the elements of this node.
no setteroverride
position → int?
Start position of this node in the source.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source → String?
Text source of this node;
finalinherited
strict → bool?
Returns true if node is strict; otherwise false.
no setterinherited
type → GlobNodeTypes
Returns the type of this node.
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
Returns srting representation.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited